<?php
/**
 * We put all translations here.
 *
 * @package Page Builder Sandwich
 */

if ( ! defined( 'ABSPATH' ) ) { exit; // Exit if accessed directly.
}

if ( ! class_exists( 'PBSTranslations' ) ) {

	/**
	 * This is where all the strings are inputted.
	 */
	class PBSTranslations {

		/**
		 * Hook into the frontend.
		 */
		function __construct() {
			add_filter( 'pbs_localize_scripts', array( $this, 'add_labels' ) );
			add_filter( 'pbs_error_notice_localize_scripts', array( $this, 'add_error_labels' ) );
		}


		/**
		 * Checks plugins for
		 */

		/**
		 * Add our translatable text.
		 *
		 * @since 2.13
		 *
		 * @param array $args Localization array.
		 *
		 * @return array The modified localization array.
		 */
		public function add_labels( $args ) {

			$args['labels'] = array(

				// Used in _element-html.js.
				'html_frame_button' => __( 'Save HTML', 'page-builder-sandwich' ),

				// Used in _element-icon.js.
				'icon_frame_change_title' => __( 'Change Icon', 'page-builder-sandwich' ),
				'icon_frame_change_button' => __( 'Change Icon', 'page-builder-sandwich' ),

				// Used in _element-newsletter.js.
				'newsletter_default_button' => __( 'Subscribe', 'page-builder-sandwich' ),

				// Used in _get-premium.js.
				'get_the_premium_plugin' => __( 'Get the Premium Plugin to get more tools and features', 'page-builder-sandwich' ),
				'premium' => __( 'Premium', 'page-builder-sandwich' ),

				// Used in _inspector-newsletter.js.
				'icon_label' => __( 'Icon Label', 'page-builder-sandwich' ),
				'newsletter' => __( 'Newsletter', 'page-builder-sandwich' ),
				'show_button_when_typed_on' => __( 'Only Show Button When Typed On', 'page-builder-sandwich' ),
				'error_message_color' => __( 'Error Message Text Color', 'page-builder-sandwich' ),
				'success_message_color' => __( 'Success Message Text Color', 'page-builder-sandwich' ),
				'success_message' => __( 'Success Message', 'page-builder-sandwich' ),
				'thank_you_for_subscribing' => __( 'Thank you for subscribing!', 'page-builder-sandwich' ),
				'newsletter_service' => __( 'Newsletter Service', 'page-builder-sandwich' ),
				'newsletter_settings' => __( 'Newsletter Settings', 'page-builder-sandwich' ),
				'mailchimp_api_key' => __( 'MailChimp API Key', 'page-builder-sandwich' ),
				'get_mailchimp_api_key' => __( 'Get your MailChimp API Key', 'page-builder-sandwich' ),
				'mailchimp_list_key' => __( 'MailChimp List Key', 'page-builder-sandwich' ),
				'get_mailchimp_list_key' => __( 'Get your MailChimp List Key', 'page-builder-sandwich' ),
				'aweber_list_id' => __( 'AWeber List ID', 'page-builder-sandwich' ),
				'get_aweber_list_id' => __( 'Get your AWeber List ID', 'page-builder-sandwich' ),
				'mailpoet_list' => __( 'MailPoet List', 'page-builder-sandwich' ),

				// Used in _inspector-options.js.
				'widget_properties_title' => __( '%s Widget Properties', 'page-builder-sandwich' ),

				// Used in _inspector-sidebar.js.
				'sidebar_inspector_desc' => __( 'Add a sidebar or widget area', 'page-builder-sandwich' ),
				'select_a_sidebar' => __( 'Select a Sidebar', 'page-builder-sandwich' ),

				// Used in _inspector-widgets.js.
				'widget_inspector_desc' => __( 'Add a WordPress widget', 'page-builder-sandwich' ),

				// Used in _inspector.js.
				'shortcodes_not_attributes_detected' => __( 'No attributes or content detected', 'page-builder-sandwich' ),
				'no_attributes_available' => __( 'No attributes available.', 'page-builder-sandwich' ),
				'inspector_title' => __( '%s Properties', 'page-builder-sandwich' ),
				'note_options_are_detected' => __( 'Options are detected from usage of this shortcode', 'page-builder-sandwich' ),
				'note_shortcode_not_appearing' => __( "Note: If the element doesn't show up, you may need to refresh the page.", 'page-builder-sandwich' ),

				// Used in _pbs-stats-tracking.js.
				'optin_error' => __( 'Communication error, please refresh the page and try again', 'page-builder-sandwich' ),

				// Inspector labels.
				'post_title' => __( 'Post Title', 'page-builder-sandwich' ),
				'your_text_here' => __( 'Your Text Here', 'page-builder-sandwich' ),
				'spacer' => __( 'Spacer', 'page-builder-sandwich' ),
				'social_icons' => __( 'Social Icons', 'page-builder-sandwich' ),
				'vertical' => __( 'Vertical', 'page-builder-sandwich' ),
				'horizontal' => __( 'Horizontal', 'page-builder-sandwich' ),
				'content_orientation' => __( 'Content Orientation', 'page-builder-sandwich' ),
				'desc_content_orientation' => __( 'Elements are placed vertically by default, you can change it here.', 'page-builder-sandwich' ),
				'desc_icon_url' => __( 'Turn your icon into a link.', 'page-builder-sandwich' ),
				'pricing_table' => __( 'Pricing Table', 'page-builder-sandwich' ),
				'special_elements' => __( 'Special Elements', 'page-builder-sandwich' ),
				'use_page_template' => __( 'Use Page Template', 'page-builder-sandwich' ),
				'page_templates' => __( 'Page Templates', 'page-builder-sandwich' ),
				'replace_contents_with_template' => __( 'Replace Contents With Template', 'page-builder-sandwich' ),
				'hide_in_tablets' => __( 'Hide in tablets', 'page-builder-sandwich' ),
				'hide_in_phones' => __( 'Hide in phones', 'page-builder-sandwich' ),
				'properties_inspector' => __( 'Properties Inspector', 'page-builder-sandwich' ),
				'general' => __( 'General', 'page-builder-sandwich' ),
				'page_heading' => __( 'Page Heading', 'page-builder-sandwich' ),
				'team_members' => __( 'Team Members', 'page-builder-sandwich' ),
				'featurette' => __( 'Featurette', 'page-builder-sandwich' ),
				'gallery' => __( 'Gallery', 'page-builder-sandwich' ),
				'testimonial' => __( 'Testimonial', 'page-builder-sandwich' ),
				'call_to_action' => __( 'Call To Action', 'page-builder-sandwich' ),
				'pricing' => __( 'Pricing', 'page-builder-sandwich' ),
				'icon_list_one' => __( 'Icon List 1', 'page-builder-sandwich' ),
				'icon_list_two' => __( 'Icon List 2', 'page-builder-sandwich' ),
				'image_box' => __( 'Image Box', 'page-builder-sandwich' ),
				'instagram_feed' => __( 'Instagram Feed', 'page-builder-sandwich' ),
				'youtube' => __( 'Youtube', 'page-builder-sandwich' ),
				'contact_details' => __( 'Contact Details', 'page-builder-sandwich' ),
				'contact_form7' => __( 'Contact Form 7', 'page-builder-sandwich' ),
				'woocommerce' => __( 'WooCommerce', 'page-builder-sandwich' ),
				'advanced_custom_fields' => __( 'ACF', 'page-builder-sandwich' ),
				'nextgen' => __( 'NextGEN', 'page-builder-sandwich' ),
				'events_calendar' => __( 'Events Calendar', 'page-builder-sandwich' ),
				'countdown_to_date' => __( 'Countdown to Date', 'page-builder-sandwich' ),
				'desc_countdown_to_date' => __( 'Format: YYYY/MM/DD HH:MM:SS For Example: 2018/01/20 00:00:00', 'page-builder-sandwich' ),
				'display_size' => __( 'Display Size', 'page-builder-sandwich' ),
				'display_these_dates' => __( 'Display these dates', 'page-builder-sandwich' ),
				'years' => __( 'Years', 'page-builder-sandwich' ),
				'months' => __( 'Months', 'page-builder-sandwich' ),
				'weeks' => __( 'Weeks', 'page-builder-sandwich' ),
				'days' => __( 'Days', 'page-builder-sandwich' ),
				'hours' => __( 'Hours', 'page-builder-sandwich' ),
				'minutes' => __( 'Minutes', 'page-builder-sandwich' ),
				'seconds' => __( 'Seconds', 'page-builder-sandwich' ),
				'countdown' => __( 'Countdown', 'page-builder-sandwich' ),
				'count_up' => __( 'Count Up', 'page-builder-sandwich' ),
				'float' => __( 'Float', 'page-builder-sandwich' ),
				'none_centered' => sprintf( __( '%s (%s)', 'page-builder-sandwich' ), __( 'None', 'page-builder-sandwich' ), __( 'Center', 'page-builder-sandwich' ) ),
				'years_label' => sprintf( __( '%s Label', 'page-builder-sandwich' ), __( 'Years', 'page-builder-sandwich' ) ),
				'months_label' => sprintf( __( '%s Label', 'page-builder-sandwich' ), __( 'Months', 'page-builder-sandwich' ) ),
				'weeks_label' => sprintf( __( '%s Label', 'page-builder-sandwich' ), __( 'Weeks', 'page-builder-sandwich' ) ),
				'days_label' => sprintf( __( '%s Label', 'page-builder-sandwich' ), __( 'Days', 'page-builder-sandwich' ) ),
				'hours_label' => sprintf( __( '%s Label', 'page-builder-sandwich' ), __( 'Hours', 'page-builder-sandwich' ) ),
				'minutes_label' => sprintf( __( '%s Label', 'page-builder-sandwich' ), __( 'Minutes', 'page-builder-sandwich' ) ),
				'seconds_label' => sprintf( __( '%s Label', 'page-builder-sandwich' ), __( 'Seconds', 'page-builder-sandwich' ) ),
				'count_up_numbers' => __( 'Animate Number Counting', 'page-builder-sandwich' ),
				'count_up_time' => __( 'Count Up Duration', 'page-builder-sandwich' ),
				'count_up_delay' => __( 'Count Up Tick Delay', 'page-builder-sandwich' ),
				'input_field' => __( 'Input Field', 'page-builder-sandwich' ),
				'edit_link' => sprintf( __( 'Edit %s', 'page-builder-sandwich' ), __( 'Link', 'page-builder-sandwich' ) ),
				'button_padding' => __( 'Button Padding', 'page-builder-sandwich' ),
				'pick_an_icon' => __( 'Pick an icon', 'page-builder-sandwich' ),
				'button_color' => __( 'Button Color', 'page-builder-sandwich' ),
				'button_text_color' => __( 'Button Text Color', 'page-builder-sandwich' ),
				'vertical_padding' => __( 'Vertical Padding', 'page-builder-sandwich' ),
				'horizontal_padding' => __( 'Horizontal Padding', 'page-builder-sandwich' ),
				'ghost_button_style' => __( 'Use Ghost Button Style', 'page-builder-sandwich' ),
				'choose_button_icon' => __( 'Choose Button Icon', 'page-builder-sandwich' ),
				'button_icon' => __( 'Button Icon', 'page-builder-sandwich' ),
				'use_icon' => __( 'Use Icon', 'page-builder-sandwich' ),
				'icon_color' => __( 'Icon Color', 'page-builder-sandwich' ),
				'move' => __( 'Move', 'page-builder-sandwich' ),
				'move_carousel' => sprintf( __( 'Move %s', 'page-builder-sandwich' ), __( 'Carousel', 'page-builder-sandwich' ) ),
				'move_left' => __( 'Move Left', 'page-builder-sandwich' ),
				'move_right' => __( 'Move Right', 'page-builder-sandwich' ),
				'default' => __( 'Default', 'page-builder-sandwich' ),
				'inside_left' => __( 'Inside Left', 'page-builder-sandwich' ),
				'inside_center' => __( 'Inside Center', 'page-builder-sandwich' ),
				'inside_right' => __( 'Inside Right', 'page-builder-sandwich' ),
				'icon_size' => __( 'Icon Size', 'page-builder-sandwich' ),
				'horizontal_offset' => __( 'Horizontal Offset', 'page-builder-sandwich' ),
				'full_height' => __( 'Full Height', 'page-builder-sandwich' ),
				'full_width' => __( 'Full-Width', 'page-builder-sandwich' ),
				'normal_width' => __( 'Normal Width', 'page-builder-sandwich' ),
				'full_height' => __( 'Full-Height', 'page-builder-sandwich' ),
				'automatic_height' => __( 'Automatic Height', 'page-builder-sandwich' ),
				'move_slide_left' => __( 'Move Slide Left', 'page-builder-sandwich' ),
				'slides' => __( 'Slides', 'page-builder-sandwich' ),
				'move_slide_right' => __( 'Move Slide Right', 'page-builder-sandwich' ),
				'remove_slide' => sprintf( __( 'Remove %s', 'page-builder-sandwich' ), __( 'Slide', 'page-builder-sandwich' ) ),
				'add_slide' => sprintf( __( 'Add %s', 'page-builder-sandwich' ), __( 'Slide', 'page-builder-sandwich' ) ),
				'clone_slide' => sprintf( __( 'Clone %s', 'page-builder-sandwich' ), __( 'Slide', 'page-builder-sandwich' ) ),
				'bullet' => __( 'Bullet', 'page-builder-sandwich' ),
				'bullet_color' => __( 'Bullet Color', 'page-builder-sandwich' ),
				'bullets' => __( 'Bullets', 'page-builder-sandwich' ),
				'bullet_location' => __( 'Bullet Location', 'page-builder-sandwich' ),
				'slide_delay' => __( 'Slide Delay', 'page-builder-sandwich' ),
				'embed' => __( 'Embed', 'page-builder-sandwich' ),
				'embedded_url' => __( 'Embedded URL', 'page-builder-sandwich' ),
				'desc_embedded_url' => sprintf( __( 'Paste the URL you want to embed here via oEmbed. You can view a list of all websites that you can embed from the %sWordPress Codex%s.', 'page-builder-sandwich' ), '<a href="https://codex.wordpress.org/Embeds#Okay.2C_So_What_Sites_Can_I_Embed_From.3F" target="_blank">', '</a>' ),
				'delete' => __( 'Delete', 'page-builder-sandwich' ),
				'delete_carousel' => sprintf( __( 'Delete %s', 'page-builder-sandwich' ), __( 'Carousel', 'page-builder-sandwich' ) ),
				'row_width' => __( 'Row Width', 'page-builder-sandwich' ),
				'desc_row_width' => __( 'Let your row occupy the whole browser width. This only affects the outer-most row.', 'page-builder-sandwich' ),
				'full_width_retained_content_width' => __( 'Full-Width Retained Content Width', 'page-builder-sandwich' ),
				'normal' => __( 'Normal', 'page-builder-sandwich' ),
				'fixed_image_background' => __( 'Fixed Image Background', 'page-builder-sandwich' ),
				'desc_fixed_image_background' => __( 'Make your background image stick to the window as an effect', 'page-builder-sandwich' ),
				'background_color' => __( 'Background Color', 'page-builder-sandwich' ),
				'background_color_focused' => __( 'Background Color (When Focused)', 'page-builder-sandwich' ),
				'desc_icon_tooltip' => __( 'Add text to enable tooltip.', 'page-builder-sandwich' ),
				'background' => __( 'Background', 'page-builder-sandwich' ),
				'desc_background_tint' => __( 'Use the background color picker above to add color. Also works for parallax and video backgrounds.', 'page-builder-sandwich' ),
				'background_size' => __( 'Background Size', 'page-builder-sandwich' ),
				'desc_background_size' => __( 'Turn your background image into a pattern.', 'page-builder-sandwich' ),
				'image' => __( 'Image', 'page-builder-sandwich' ),
				'background_image' => __( 'Background Image', 'page-builder-sandwich' ),
				'vertical_column_alignment' => __( 'Vertical Column Alignment', 'page-builder-sandwich' ),
				'desc_vertical_column_alignment' => __( 'The alignment of the column vertically. Helpful if the row is tall because of other columns, and this column is short.', 'page-builder-sandwich' ),
				'occupy_entire_space' => __( 'Occupy entire space', 'page-builder-sandwich' ),
				'alignment' => __( 'Alignment', 'page-builder-sandwich' ),
				'reset_alignment' => __( 'Reset Alignment', 'page-builder-sandwich' ),
				'vertical_content_alignment' => __( 'Vertical Content Alignment', 'page-builder-sandwich' ),
				'desc_vertical_content_alignment' => __( 'The alignment of the content inside this column vertically. Helpful if the column is tall and only has a short content.', 'page-builder-sandwich' ),
				'spread_evenly_top_to_bottom' => __( 'Spread evenly from top to bottom (space-between)', 'page-builder-sandwich' ),
				'equally_spaced' => __( 'Each item is equally spaced (space-around)', 'page-builder-sandwich' ),
				'horizontal_content_alignment' => __( 'Horizontal Content Alignment', 'page-builder-sandwich' ),
				'desc_horizontal_content_alignment' => __( 'The alignment of the content inside this column horizontally. Helpful for specifying alignment all at once.', 'page-builder-sandwich' ),
				'add_column' => sprintf( __( 'Add %s', 'page-builder-sandwich' ), __( 'Column', 'page-builder-sandwich' ) ),
				'clear_all_row_styles' => __( 'Clear All Row Styles', 'page-builder-sandwich' ),
				'clone_row' => sprintf( __( 'Clone %s', 'page-builder-sandwich' ), __( 'Row', 'page-builder-sandwich' ) ),
				'delete_row' => sprintf( __( 'Delete %s', 'page-builder-sandwich' ), __( 'Row', 'page-builder-sandwich' ) ),
				'clear_all_column_styles' => __( 'Clear All Column Styles', 'page-builder-sandwich' ),
				'row' => __( 'Row', 'page-builder-sandwich' ),
				'column' => __( 'Column', 'page-builder-sandwich' ),
				'clone_column' => sprintf( __( 'Clone %s', 'page-builder-sandwich' ), __( 'Column', 'page-builder-sandwich' ) ),
				'delete_column' => sprintf( __( 'Delete %s', 'page-builder-sandwich' ), __( 'Column', 'page-builder-sandwich' ) ),
				'delete_slide' => sprintf( __( 'Delete %s', 'page-builder-sandwich' ), __( 'Slide', 'page-builder-sandwich' ) ),
				'border_color' => __( 'Border Color', 'page-builder-sandwich' ),
				'list' => __( 'List', 'page-builder-sandwich' ),
				'borders' => __( 'Borders', 'page-builder-sandwich' ),
				'solid' => __( 'Solid', 'page-builder-sandwich' ),
				'dashed' => __( 'Dashed', 'page-builder-sandwich' ),
				'dotted' => __( 'Dotted', 'page-builder-sandwich' ),
				'border_style' => __( 'Border Style', 'page-builder-sandwich' ),
				'thickness' => __( 'Thickness', 'page-builder-sandwich' ),
				'border_thickness' => __( 'Border Thickness', 'page-builder-sandwich' ),
				'border_radius' => __( 'Border Radius', 'page-builder-sandwich' ),
				'toggle_background_image_tint' => __( 'Toggle Background Tint', 'page-builder-sandwich' ),
				'convert_to_1_column' => sprintf( __( 'Convert to %s', 'page-builder-sandwich' ), __( '1 Column', 'page-builder-sandwich' ) ),
				'edit_image' => sprintf( __( 'Edit %s', 'page-builder-sandwich' ), __( 'Image', 'page-builder-sandwich' ) ),
				'open_media_manager' => sprintf( __( 'Open %s', 'page-builder-sandwich' ), __( 'Media Manager', 'page-builder-sandwich' ) ),
				'change_image_details' => sprintf( __( 'Change %s', 'page-builder-sandwich' ), __( 'Image Details', 'page-builder-sandwich' ) ),
				'change_columns' => sprintf( __( 'Change %s', 'page-builder-sandwich' ), __( 'Columns', 'page-builder-sandwich' ) ),
				'convert_to_even_2_columns' => sprintf( __( 'Convert to %s', 'page-builder-sandwich' ), sprintf( __( 'Even %d Columns', 'page-builder-sandwich' ), 2 ) ),
				'convert_to_uneven_2_columns' => sprintf( __( 'Convert to %s', 'page-builder-sandwich' ), sprintf( __( 'Uneven %d Columns', 'page-builder-sandwich' ), 2 ) ),
				'convert_to_even_3_columns' => sprintf( __( 'Convert to %s', 'page-builder-sandwich' ), sprintf( __( 'Even %d Columns', 'page-builder-sandwich' ), 3 ) ),
				'convert_to_uneven_3_columns' => sprintf( __( 'Convert to %s', 'page-builder-sandwich' ), sprintf( __( 'Uneven %d Columns', 'page-builder-sandwich' ), 3 ) ),
				'convert_to_even_4_columns' => sprintf( __( 'Convert to %s', 'page-builder-sandwich' ), sprintf( __( 'Even %d Columns', 'page-builder-sandwich' ), 4 ) ),
				'convert_to_uneven_4_columns' => sprintf( __( 'Convert to %s', 'page-builder-sandwich' ), sprintf( __( 'Uneven %d Columns', 'page-builder-sandwich' ), 4 ) ),
				'spacing' => __( 'Spacing', 'page-builder-sandwich' ),
				'column_width' => __( 'Column Width', 'page-builder-sandwich' ),
				'column_gap' => __( 'Column Gap', 'page-builder-sandwich' ),
				'custom_class' => __( 'Custom Class', 'page-builder-sandwich' ),
				'desc_custom_class' => __( 'Assign custom classes to this element that you can reference inside your CSS or Javascript.', 'page-builder-sandwich' ),
				'custom_id' => __( 'Custom ID', 'page-builder-sandwich' ),
				'desc_custom_id' => __( 'Assign a custom unique ID to this element that you can reference inside your CSS or Javascript.', 'page-builder-sandwich' ),
				'advanced' => __( 'Advanced', 'page-builder-sandwich' ),
				'choose_icon' => __( 'Choose Icon', 'page-builder-sandwich' ),
				'padding' => __( 'Padding', 'page-builder-sandwich' ),
				'desc_input_field_padding' => __( 'Use this to make your input field larger', 'page-builder-sandwich' ),
				'remove_icon' => sprintf( __( 'Remove %s', 'page-builder-sandwich' ), __( 'Icon', 'page-builder-sandwich' ) ),
				'shadow_hover_effect' => __( 'Animate Shadow on Hover', 'page-builder-sandwich' ),
				'width' => __( 'Width', 'page-builder-sandwich' ),
				'shadows' => __( 'Shadows', 'page-builder-sandwich' ),
				'shadow_strength' => __( 'Shadow Strength', 'page-builder-sandwich' ),
				'simple_shadow_small' => __( 'Simple Shadow Small', 'page-builder-sandwich' ),
				'simple_shadow_normal' => __( 'Simple Shadow Normal', 'page-builder-sandwich' ),
				'simple_shadow_medium' => __( 'Simple Shadow Medium', 'page-builder-sandwich' ),
				'simple_shadow_large' => __( 'Simple Shadow Large', 'page-builder-sandwich' ),
				'simple_shadow_huge' => __( 'Simple Shadow Huge', 'page-builder-sandwich' ),
				'shadow_fancy_bottom_tilted' => __( 'Fancy Bottom Tilted (Needs Background Color)', 'page-builder-sandwich' ),
				'shadow_fancy_vertical' => __( 'Fancy Vertical (Needs Background Color)', 'page-builder-sandwich' ),
				'shadow_fancy_horizontal' => __( 'Fancy Horizontal (Needs Background Color)', 'page-builder-sandwich' ),
				'shadow_fancy_center_bottom' => __( 'Fancy Center Bottom (Needs Background Color)', 'page-builder-sandwich' ),
				'tooltip' => __( 'Tooltip', 'page-builder-sandwich' ),
				'tooltip_location' => __( 'Tooltip Location', 'page-builder-sandwich' ),
				'toggle_shadow' => sprintf( __( 'Toggle %s', 'page-builder-sandwich' ), __( 'Shadow', 'page-builder-sandwich' ) ),
				'tooltip_text' => __( 'Hover Tooltip Text', 'page-builder-sandwich' ),
				'note_overridden_by_elements' => __( 'Note: this can be overridden by other elements.', 'page-builder-sandwich' ),
				'text_color' => __( 'Text Color', 'page-builder-sandwich' ),
				'text_color_focused' => __( 'Text Color (When Focused)', 'page-builder-sandwich' ),
				'text_alignment' => __( 'Text Alignment', 'page-builder-sandwich' ),
				'border' => __( 'Border', 'page-builder-sandwich' ),
				'all_sides' => __( 'All Sides', 'page-builder-sandwich' ),
				'top_and_bottom' => __( 'Top & Bottom', 'page-builder-sandwich' ),
				'left_and_right' => __( 'Left & Right', 'page-builder-sandwich' ),
				'top' => __( 'Top', 'page-builder-sandwich' ),
				'right' => __( 'Right', 'page-builder-sandwich' ),
				'bottom' => __( 'Bottom', 'page-builder-sandwich' ),
				'left' => __( 'Left', 'page-builder-sandwich' ),
				'none' => __( 'None', 'page-builder-sandwich' ),
				'all' => __( 'All', 'page-builder-sandwich' ),
				'center' => __( 'Center', 'page-builder-sandwich' ),
				'colors' => __( 'Colors', 'page-builder-sandwich' ),
				'general_and_style' => __( 'General and Style', 'page-builder-sandwich' ),
				'placeholder_color' => __( 'Placeholder Color', 'page-builder-sandwich' ),
				'placeholder_color_focused' => __( 'Placeholder Color (When Focused)', 'page-builder-sandwich' ),
				'bullet_icon' => __( 'Bullet Icon', 'page-builder-sandwich' ),
				'reset_bullet_icon' => sprintf( __( 'Reset %s', 'page-builder-sandwich' ), __( 'Bullet Icon', 'page-builder-sandwich' ) ),
				'choose_bullet_icon' => sprintf( __( 'Choose %s', 'page-builder-sandwich' ), __( 'Bullet Icon', 'page-builder-sandwich' ) ),
				'use_as_bullet' => __( 'Use As Bullet', 'page-builder-sandwich' ),
				'font' => __( 'Font', 'page-builder-sandwich' ),
				'fonts_used_in_this_page' => __( 'Fonts Used in this Page', 'page-builder-sandwich' ),
				'fonts_recently_used' => __( 'Recently Used Fonts', 'page-builder-sandwich' ),
				'fonts_all' => __( 'All Fonts', 'page-builder-sandwich' ),
				'no_results' => __( 'No results', 'page-builder-sandwich' ),
				'select_font' => __( 'Select Font', 'page-builder-sandwich' ),
				'font_size' => __( 'Font Size', 'page-builder-sandwich' ),
				'increase_font_size' => sprintf( __( 'Increase %s', 'page-builder-sandwich' ), __( 'Font Size', 'page-builder-sandwich' ) ),
				'decrease_font_size' => sprintf( __( 'Decrease %s', 'page-builder-sandwich' ), __( 'Font Size', 'page-builder-sandwich' ) ),
				'reset_font_size' => sprintf( __( 'Reset %s', 'page-builder-sandwich' ), __( 'Font Size', 'page-builder-sandwich' ) ),
				'heading_label' => __( 'Heading %d', 'page-builder-sandwich' ),
				'horizontal_rule' => __( 'Horizontal Rule', 'page-builder-sandwich' ),
				'map' => __( 'Map', 'page-builder-sandwich' ),
				'google_map' => __( 'Google Map', 'page-builder-sandwich' ),
				'text' => __( 'Text', 'page-builder-sandwich' ),
				'insert_icon' => sprintf( __( 'Insert %s', 'page-builder-sandwich' ), __( 'Icon', 'page-builder-sandwich' ) ),
				'line_height' => __( 'Line Height', 'page-builder-sandwich' ),
				'increase_line_height' => sprintf( __( 'Increase %s', 'page-builder-sandwich' ), __( 'Line Height', 'page-builder-sandwich' ) ),
				'decrease_line_height' => sprintf( __( 'Decrease %s', 'page-builder-sandwich' ), __( 'Line Height', 'page-builder-sandwich' ) ),
				'reset_line_height' => sprintf( __( 'Reset %s', 'page-builder-sandwich' ), __( 'Line Height', 'page-builder-sandwich' ) ),
				'text_formatting' => __( 'Text Formatting', 'page-builder-sandwich' ),
				'change_type' => __( 'Change Type', 'page-builder-sandwich' ),
				'elements' => __( 'Elements', 'page-builder-sandwich' ),
				'rows_and_columns' => __( 'Rows & Columns', 'page-builder-sandwich' ),
				'pre_designed_sections' => __( 'Pre-Designed Sections', 'page-builder-sandwich' ),
				'map_controls' => __( 'Map Controls', 'page-builder-sandwich' ),
				'map_api_key' => __( 'Map API Key', 'page-builder-sandwich' ),
				'map_api_key_note' => sprintf( __( 'You will need to supply your own %sGoogle Javascript Map API key in the settings page%s in order for the Map element to work. After adding an API key, refresh this page for the map to work.', 'page-builder-sandwich' ), '<a href="' . esc_url( admin_url( '/admin.php?page=page-builder-sandwich-settings' ) ) . '" target="_blank">', '</a>' ),
				'map_marker' => __( 'Map Marker', 'page-builder-sandwich' ),
				'custom_map_marker' => __( 'Custom Map Marker', 'page-builder-sandwich' ),
				'tint_map' => __( 'Tint Map', 'page-builder-sandwich' ),
				'latitude_longitude_and_address' => __( 'Latitude & Longitude / Address', 'page-builder-sandwich' ),
				'latitude_longitude_desc' => __( 'A number pair separated by a comma e.g. "37.09024, -95.712891" or enter an address', 'page-builder-sandwich' ),
				'custom_map_styles' => __( 'Custom Map Styles', 'page-builder-sandwich' ),
				'custom_map_styles_desc' => __( 'Enter custom map styles here. Read about <a href="https://developers.google.com/maps/documentation/javascript/styling#styling_the_default_map" target="_blank">Google\'s styling guide</a>. You can use sites like <a href="https://snazzymaps.com" target="_blank">SnazzyMaps.com</a> to create custom map styles.', 'page-builder-sandwich' ),
				'auto' => __( 'Auto', 'page-builder-sandwich' ),
				'move_above_s' => __( 'Move Above %s', 'page-builder-sandwich' ),
				'move_below_s' => __( 'Move Below %s', 'page-builder-sandwich' ),
				'move_inside_column' => __( 'Move Inside Column', 'page-builder-sandwich' ),
				'tab_style' => __( 'Tab Style', 'page-builder-sandwich' ),
				'tab_styles' => __( 'Tab Styles', 'page-builder-sandwich' ),
				'active_tab_background_color' => __( 'Active Tab Background Color', 'page-builder-sandwich' ),
				'active_tab_text_color' => __( 'Active Tab Text Color', 'page-builder-sandwich' ),
				'inactive_tab_text_color' => __( 'Inactive Tab Text Color', 'page-builder-sandwich' ),
				'tab_content_background_color' => __( 'Tab Content Background Color', 'page-builder-sandwich' ),
				'tab_content_text_color' => __( 'Tab Content Text Color', 'page-builder-sandwich' ),
				'overflow_hidden' => __( 'Overflow Hidden', 'page-builder-sandwich' ),
				'desc_overflow_hidden' => __( 'Hide or clip elements that go outside this area.', 'page-builder-sandwich' ),
				'classic' => __( 'Classic', 'page-builder-sandwich' ),
				'clean' => __( 'Clean', 'page-builder-sandwich' ),
				'vertical_tabs' => __( 'Vertical tabs', 'page-builder-sandwich' ),
				'tab_alignment' => __( 'Tab Alignment', 'page-builder-sandwich' ),
				'stretch' => __( 'Stretch', 'page-builder-sandwich' ),
				'properties' => __( 'Properties', 'page-builder-sandwich' ),
				'margin' => __( 'Margin', 'page-builder-sandwich' ),
				'add_tab' => sprintf( __( 'Add %s', 'page-builder-sandwich' ), __( 'Tab', 'page-builder-sandwich' ) ),
				'remove_tab' => sprintf( __( 'Remove %s', 'page-builder-sandwich' ), __( 'Tab', 'page-builder-sandwich' ) ),
				'delete_tabs' => sprintf( __( 'Delete %s', 'page-builder-sandwich' ), __( 'Tabs', 'page-builder-sandwich' ) ),
				'open' => __( 'Open', 'page-builder-sandwich' ),
				'loading_options' => __( 'Loading Options', 'page-builder-sandwich' ),
				'loading_options_errored' => __( 'Error loading options', 'page-builder-sandwich' ),
				'insert_element' => sprintf( __( 'Insert %s', 'page-builder-sandwich' ), __( 'Elements', 'page-builder-sandwich' ) ),
				'add_element' => sprintf( __( 'Add %s', 'page-builder-sandwich' ), __( 'Element', 'page-builder-sandwich' ) ),
				'fade' => __( 'Fade', 'page-builder-sandwich' ),
				'fade_up' => __( 'Fade Up', 'page-builder-sandwich' ),
				'fade_down' => __( 'Fade Down', 'page-builder-sandwich' ),
				'fade_left' => __( 'Fade Left', 'page-builder-sandwich' ),
				'fade_right' => __( 'Fade Right', 'page-builder-sandwich' ),
				'fade_up_right' => __( 'Fade Up Right', 'page-builder-sandwich' ),
				'fade_up_left' => __( 'Fade Up Left', 'page-builder-sandwich' ),
				'fade_down_right' => __( 'Fade Down Right', 'page-builder-sandwich' ),
				'fade_down_left' => __( 'Fade Down Left', 'page-builder-sandwich' ),
				'flip_up' => __( 'Flip Up', 'page-builder-sandwich' ),
				'flip_down' => __( 'Flip Down', 'page-builder-sandwich' ),
				'flip_left' => __( 'Flip Left', 'page-builder-sandwich' ),
				'flip_right' => __( 'Flip Right', 'page-builder-sandwich' ),
				'roll_3d_bottom_to_top' => __( 'Roll 3D Bottom to Top', 'page-builder-sandwich' ),
				'roll_3d_left_to_right' => __( 'Roll 3D Left to Right', 'page-builder-sandwich' ),
				'roll_3d_right_to_left' => __( 'Roll 3D Right to Left', 'page-builder-sandwich' ),
				'spin' => __( 'Spin', 'page-builder-sandwich' ),
				'spin_reverse' => __( 'Spin Reverse', 'page-builder-sandwich' ),
				'spin_3d' => __( 'Spin 3D', 'page-builder-sandwich' ),
				'spin_3d_reverse' => __( 'Spin 3D Reverse', 'page-builder-sandwich' ),
				'slide_up' => __( 'Slide Up', 'page-builder-sandwich' ),
				'slide_down' => __( 'Slide Down', 'page-builder-sandwich' ),
				'slide_left' => __( 'Slide Left', 'page-builder-sandwich' ),
				'slide_right' => __( 'Slide Right', 'page-builder-sandwich' ),
				'rotate_top_left' => __( 'Rotate Top Left', 'page-builder-sandwich' ),
				'rotate_top_right' => __( 'Rotate Top Right', 'page-builder-sandwich' ),
				'rotate_bottom_left' => __( 'Rotate Bottom Left', 'page-builder-sandwich' ),
				'rotate_bottom_right' => __( 'Rotate Bottom Right', 'page-builder-sandwich' ),
				'zoom_in' => __( 'Zoom In', 'page-builder-sandwich' ),
				'zoom_in_up' => __( 'Zoom In Up', 'page-builder-sandwich' ),
				'zoom_in_down' => __( 'Zoom In Down', 'page-builder-sandwich' ),
				'zoom_in_left' => __( 'Zoom In Left', 'page-builder-sandwich' ),
				'zoom_in_right' => __( 'Zoom In Right', 'page-builder-sandwich' ),
				'zoom_out' => __( 'Zoom Out', 'page-builder-sandwich' ),
				'zoom_out_up' => __( 'Zoom Out Up', 'page-builder-sandwich' ),
				'zoom_out_down' => __( 'Zoom Out Down', 'page-builder-sandwich' ),
				'zoom_out_left' => __( 'Zoom Out Left', 'page-builder-sandwich' ),
				'zoom_out_right' => __( 'Zoom Out Right', 'page-builder-sandwich' ),
				'loop_pulsate' => __( 'Pulsate (Loop)', 'page-builder-sandwich' ),
				'loop_pulsate_fade' => __( 'Pulsate Fade (Loop)', 'page-builder-sandwich' ),
				'loop_hover' => __( 'Hover (Loop)', 'page-builder-sandwich' ),
				'loop_hover_float' => __( 'Hover Floar (Loop)', 'page-builder-sandwich' ),
				'loop_wobble' => __( 'Wobble (Loop)', 'page-builder-sandwich' ),
				'loop_wobble_3d' => __( 'Wobble 3D (Loop)', 'page-builder-sandwich' ),
				'loop_dangle' => __( 'Dangle (Loop)', 'page-builder-sandwich' ),
				'animation' => __( 'Animation', 'page-builder-sandwich' ),
				'entrance_animation' => __( 'Entrance Animation', 'page-builder-sandwich' ),
				'option_animation_name' => __( 'Entrance Animation', 'page-builder-sandwich' ),
				'animation_speed' => __( 'Animation Speed', 'page-builder-sandwich' ),
				'in_milliseconds' => __( 'In milliseconds', 'page-builder-sandwich' ),
				'ms' => __( 'ms', 'page-builder-sandwich' ),
				'px' => __( 'px', 'page-builder-sandwich' ),
				'em' => __( 'em', 'page-builder-sandwich' ),
				'animation_start_delay' => __( 'Animation Start Delay', 'page-builder-sandwich' ),
				'desc_animation_start_delay' => __( 'Only for entrance animations.', 'page-builder-sandwich' ),
				'option_elastic_animation_name' => __( 'Elastic/Bouncy Animation', 'page-builder-sandwich' ),
				'desc_elastic_animation' => __( 'Turn this on for a bouncy/elastic animation effect.', 'page-builder-sandwich' ),
				'option_play_animation_once_name' => __( 'Animate Entrance Only Once', 'page-builder-sandwich' ),
				'toggle' => __( 'Toggle', 'page-builder-sandwich' ),
				'fade_animation' => __( 'Fade Animation', 'page-builder-sandwich' ),
				'desc_fade_animation' => __( 'Use fade instead of a sliding animation. This will disable dragging on the carousel.', 'page-builder-sandwich' ),
				'parallax' => __( 'Parallax', 'page-builder-sandwich' ),
				'desc_parallax' => __( 'A positive number will add an upward parallax.', 'page-builder-sandwich' ),
				'video_background' => __( 'Video Background', 'page-builder-sandwich' ),
				'normal_background_image' => __( 'Normal Background Image', 'page-builder-sandwich' ),
				'fixed_background_image' => __( 'Fixed Background Image', 'page-builder-sandwich' ),
				'parallax_image' => __( 'Parallax Image', 'page-builder-sandwich' ),
				'video_background_youtube_vimeo' => __( 'Video Background (YouTube or Vimeo)', 'page-builder-sandwich' ),
				'video_background_uploaded' => __( 'Video Background (Uploaded Video)', 'page-builder-sandwich' ),
				'background_image_type' => __( 'Fancy Background Effect', 'page-builder-sandwich' ),
				'desc_video_background' => __( 'Paste a URL to a YouTube or Vimeo video. Video backgrounds do not work in mobile devices, the color or image above will be used as a fallback.', 'page-builder-sandwich' ),
				'webm_video' => __( 'Background .WEBM Video', 'page-builder-sandwich' ),
				'desc_webm_video' => __( 'Pick a video of a WEBM format. You\'ll need to pick this and the MP4 format below. Video backgrounds do not work in mobile devices, the color or image above will be used as a fallback.', 'page-builder-sandwich' ),
				'mp4_video' => __( 'Video Background .MP4 Video', 'page-builder-sandwich' ),
				'desc_mp4_video' => __( 'Pick a video of an MP4 format.', 'page-builder-sandwich' ),
				'kenburns_images' => __( 'Ken Burns Images', 'page-builder-sandwich' ),
				'desc_kenburns_images' => __( 'Pick 2-4 images to rotate in the effect.', 'page-builder-sandwich' ),

				// Tools.
				'text_style' => __( 'Text Style', 'page-builder-sandwich' ),
				'heading_1' => sprintf( __( 'Heading %d', 'page-builder-sandwich' ), 1 ),
				'heading_2' => sprintf( __( 'Heading %d', 'page-builder-sandwich' ), 2 ),
				'heading_3' => sprintf( __( 'Heading %d', 'page-builder-sandwich' ), 3 ),
				'heading_4' => sprintf( __( 'Heading %d', 'page-builder-sandwich' ), 4 ),
				'heading_5' => sprintf( __( 'Heading %d', 'page-builder-sandwich' ), 5 ),
				'heading_6' => sprintf( __( 'Heading %d', 'page-builder-sandwich' ), 6 ),
				'blockquote' => __( 'Blockquote', 'page-builder-sandwich' ),
				'preformatted' => __( 'Preformatted', 'page-builder-sandwich' ),
				'paragraph' => __( 'Paragraph', 'page-builder-sandwich' ),
				'button' => __( 'Button', 'page-builder-sandwich' ),
				'carousel' => __( 'Carousel', 'page-builder-sandwich' ),
				'clear_formatting' => __( 'Clear Formatting', 'page-builder-sandwich' ),
				'code' => __( 'Code', 'page-builder-sandwich' ),
				'color' => __( 'Color', 'page-builder-sandwich' ),
				'add_row' => sprintf( __( 'Add %s', 'page-builder-sandwich' ), __( 'Row', 'page-builder-sandwich' ) ),
				'one_column' => sprintf( __( '%s Column', 'page-builder-sandwich' ), 1 ),
				'two_column' => sprintf( __( '%s Columns', 'page-builder-sandwich' ), 2 ),
				'three_column' => sprintf( __( '%s Columns', 'page-builder-sandwich' ), 3 ),
				'four_column' => sprintf( __( '%s Columns', 'page-builder-sandwich' ), 4 ),
				'add_2_column_row' => sprintf( __( 'Add a %s-Column Row', 'page-builder-sandwich' ), 2 ),
				'add_3_column_row' => sprintf( __( 'Add a %s-Column Row', 'page-builder-sandwich' ), 3 ),
				'add_4_column_row' => sprintf( __( 'Add a %s-Column Row', 'page-builder-sandwich' ), 4 ),
				'add_23_13_column_row' => sprintf( __( 'Add a %s-Column Row', 'page-builder-sandwich' ), '2/3-1/3' ),
				'add_13_23_column_row' => sprintf( __( 'Add a %s-Column Row', 'page-builder-sandwich' ), '1/3-2/3' ),
				'add_14_12_14_column_row' => sprintf( __( 'Add a %s-Column Row', 'page-builder-sandwich' ), '1/4-1/2-1/4' ),
				'add_n_column_row' => __( 'Add an N-Column Row', 'page-builder-sandwich' ),
				'html' => __( 'HTML', 'page-builder-sandwich' ),
				'iframe' => __( 'Iframe', 'page-builder-sandwich' ),
				'icon' => __( 'Icon', 'page-builder-sandwich' ),
				'justify' => __( 'Justify', 'page-builder-sandwich' ),
				'media' => __( 'Media', 'page-builder-sandwich' ),
				'newsletter_signup_form' => __( 'Newsletter Signup Form', 'page-builder-sandwich' ),
				'table' => __( 'Table', 'page-builder-sandwich' ),
				'shortcode' => __( 'Shortcode', 'page-builder-sandwich' ),
				'insert_shortcode' => __( 'Insert Shortcode', 'page-builder-sandwich' ),
				'undo' => __( 'Undo', 'page-builder-sandwich' ),
				'redo' => __( 'Redo', 'page-builder-sandwich' ),
				'sidebar_or_widget_area' => __( 'Sidebar or Widget Area', 'page-builder-sandwich' ),
				'sidebar' => __( 'Sidebar', 'page-builder-sandwich' ),
				'strikethrough' => __( 'Strikethrough', 'page-builder-sandwich' ),
				'more_tools' => __( 'More Tools', 'page-builder-sandwich' ),
				'less_tools' => __( 'Less Tools', 'page-builder-sandwich' ),
				'underline' => __( 'Underline', 'page-builder-sandwich' ),
				'uppercase' => __( 'Uppercase', 'page-builder-sandwich' ),
				'reset_case' => __( 'Reset Case', 'page-builder-sandwich' ),
				'insert_widget' => sprintf( __( 'Insert %s', 'page-builder-sandwich' ), __( 'Widget', 'page-builder-sandwich' ) ),
				'edit_html' => sprintf( __( 'Edit %s', 'page-builder-sandwich' ), __( 'HTML', 'page-builder-sandwich' ) ),
				'align_left' => __( 'Align left', 'page-builder-sandwich' ),
				'align_center' => __( 'Align center', 'page-builder-sandwich' ),
				'align_right' => __( 'Align right', 'page-builder-sandwich' ),
				'edit' => __( 'Edit', 'page-builder-sandwich' ),
				'align_none' => __( 'Align None', 'page-builder-sandwich' ),
				'edit_shortcode' => sprintf( __( 'Edit %s', 'page-builder-sandwich' ), __( 'Shortcode', 'page-builder-sandwich' ) ),
				'insert_design' => __( 'Insert Design', 'page-builder-sandwich' ),
				'insert_content' => __( 'Insert Content', 'page-builder-sandwich' ),
				'tab' => __( 'Tab', 'page-builder-sandwich' ),
				'tabs' => __( 'Tabs', 'page-builder-sandwich' ),
				's_attribute' => __( '%s attribute', 'page-builder-sandwich' ),
				'select_one' => __( 'Select one', 'page-builder-sandwich' ),
				'select_a_post_type' => __( 'Select a post type', 'page-builder-sandwich' ),
				'bold' => __( 'Bold', 'page-builder-sandwich' ),
				'italic' => __( 'Italic', 'page-builder-sandwich' ),
				'link' => __( 'Link', 'page-builder-sandwich' ),
				'bullet_list' => __( 'Bullet List', 'page-builder-sandwich' ),
				'numbered_list' => __( 'Numbered List', 'page-builder-sandwich' ),
				'indent' => __( 'Indent', 'page-builder-sandwich' ),
				'unindent' => __( 'Unindent', 'page-builder-sandwich' ),

				// Tooltips.
				'visit_link' => __( 'Visit Link', 'page-builder-sandwich' ),
				'edit_link' => sprintf( __( 'Edit %s', 'page-builder-sandwich' ), __( 'Link', 'page-builder-sandwich' ) ),
				'unlink' => __( 'Unlink', 'page-builder-sandwich' ),
				'clone' => __( 'Clone', 'page-builder-sandwich' ),
				'remove_column' => sprintf( __( 'Remove %s', 'page-builder-sandwich' ), __( 'Column', 'page-builder-sandwich' ) ),
				'edit_embed' => sprintf( __( 'Edit %s', 'page-builder-sandwich' ), __( 'Embed', 'page-builder-sandwich' ) ),
				'remove' => __( 'Remove', 'page-builder-sandwich' ),

				// Various uses.
				'sidebar' => __( 'Sidebar', 'page-builder-sandwich' ),
				'widget' => __( 'Widget', 'page-builder-sandwich' ),
				'next' => __( 'Next', 'page-builder-sandwich' ),
				'close' => __( 'Close', 'page-builder-sandwich' ),
				'select_image' => __( 'Select Image', 'page-builder-sandwich' ),
				'select_file' => __( 'Select File', 'page-builder-sandwich' ),
				'use_selected_image' => __( 'Use Selected Image', 'page-builder-sandwich' ),
				'your_email_address' => esc_attr( __( 'Your email address', 'page-builder-sandwich' ) ),
				'drag_an_element' => __( 'Drag an element below into your content', 'page-builder-sandwich' ),
				'view_template' => __( 'View Template', 'page-builder-sandwich' ),

				// Admin bar.
				'save_and_update' => __( 'Save and Update', 'page-builder-sandwich' ),
				'save_as_draft' => __( 'Save as Draft', 'page-builder-sandwich' ),
				'save_as_pending' => __( 'Save as Pending Review', 'page-builder-sandwich' ),
			);
			return $args;
		}


		/**
		 * Add localization scripts in the error notices.
		 *
		 * @since 2.13
		 *
		 * @param array $args Localization params.
		 *
		 * @return array Localization params.
		 */
		public function add_error_labels( $args ) {
			$args['labels'] = array(
				'toolbar_notice' => __( 'Please turn on your admin toolbar from your user profile in order for Page Builder Sandwich to work correctly.', 'page-builder-sandwich' ),
				'error_notice' => __( "There are errors on this page that may affect Page Builder Sandwich from working correctly. Please check the browser's console for the errors. These would need to be fixed first. Please contact the theme/plugin author", 'page-builder-sandwich' ),
			);
			return $args;
		}
	}
}

new PBSTranslations();
